@@ -1,7 +1,8 @@
+//!
 //! Postgres store
 
-pub use event_store::*;
-pub use query_store::*;
+pub use event_store::EventStore;
+pub use query_store::QueryStore;
 
 mod event_store;
 mod query_store;
